@@ -2,10 +2,10 @@ collapse =
   function(D, pos=FALSE, na.rm=TRUE) {
     # Calculates a frequency vector F from a population vector D
     # Arguments:  D  = population vector
-    #            pos = positions of the categories (necessary if there are categories with 0 observations)
-    #                 if nothing i provided, we assume observations in all categories
-    #                 e.g. if position 2 is not present in the population, no 0 will be added
-    #         na.rm = NA are removed (default)
+    #            pos = positions of the categories
+    #                  (necessary if categories with 0 observations exist)
+    #                  if not provided, we assume observations in all categories
+    #          na.rm = NA are removed (default)
     if(na.rm == TRUE) {
       # remove NA from vector, as.numeric() to get back the vector
       D = as.numeric(na.omit(D))
@@ -19,7 +19,7 @@ collapse =
       warning("Warning: Expected a numeric value in the vector.")
       return(NA)}
     if(is.na(D[1]) == TRUE) {
-      # fail if NA are found of empty
+      # fail with warning if NA are found or empty
       warning("Warning: Expected a vector, vector is empty, or vector starts with NA.")
       return(NA)}
     T = as.data.frame(table(D))  # table(D) to count frequencies
@@ -32,11 +32,11 @@ collapse =
       F = rep(0,k)     # empty with length(k)
       V = unique(D)    # chooses the categories (positions) of the values in F2
       V = V[!is.na(V)] # remove NA from unique values
-      V = sort(V)      # keeping order that is messed up by the preceding line
+      V = sort(V)      # keep order that is messed up by the preceding line
       m = length(V)    # number of non-zero values to be filled into F
       for(i in 1:m) {
         for(j in 1:k) {
-          if (pos[j] == V[i]) F[j] <- F2[i] # fill in frequencies at the correct positions
+          if (pos[j] == V[i]) F[j] = F2[i] # fill in frequencies at the correct positions
         }
       }
     }
